@@ -24,7 +24,6 @@ Copyright_License {
 #ifndef XCSOAR_WIDGET_DIALOG_HPP
 #define XCSOAR_WIDGET_DIALOG_HPP
 
-#include "Screen/Point.hpp"
 #include "Form/Form.hpp"
 #include "Form/ButtonPanel.hpp"
 #include "Widget/ManagedWidget.hpp"
@@ -38,6 +37,8 @@ class WidgetDialog : public WndForm {
 
   ManagedWidget widget;
 
+  bool full;
+
   bool auto_size;
 
   bool changed;
@@ -91,6 +92,19 @@ public:
     return AddButton(caption, *this, modal_result);
   }
 
+  WndButton *AddSymbolButton(const TCHAR *caption,
+                             ActionListener &listener, int id) {
+    return buttons.AddSymbol(caption, listener, id);
+  }
+
+  void AddButtonKey(unsigned key_code) {
+    return buttons.AddKey(key_code);
+  }
+
+  void AddAltairButtonKey(unsigned key_code) {
+    return buttons.AddAltairKey(key_code);
+  }
+
   int ShowModal();
 
   /* virtual methods from class ActionListener */
@@ -103,6 +117,11 @@ protected:
   /* virtual methods from class Window */
   virtual void OnDestroy() override;
   virtual void OnResize(PixelSize new_size) override;
+
+  /* virtual methods from class WndForm */
+  virtual void ReinitialiseLayout(const PixelRect &parent_rc) override;
+  virtual void SetDefaultFocus() override;
+  virtual bool OnAnyKeyDown(unsigned key_code) override;
 };
 
 /**
