@@ -103,7 +103,7 @@ RunContest(AbstractContest &_contest,
   // by subsequent calls
   SolverResult r = _contest.Solve(exhaustive);
   if (r != SolverResult::VALID)
-    return r != SolverResult::INCOMPLETE;
+    return false;
 
   // if no improved solution was found, must have finished processing
   // with invalid data
@@ -123,6 +123,9 @@ ContestManager::UpdateIdle(bool exhaustive)
   bool retval = false;
 
   switch (contest) {
+  case Contest::NONE:
+    break;
+
   case Contest::OLC_SPRINT:
     retval = RunContest(olc_sprint, stats.result[0],
                         stats.solution[0], exhaustive);
