@@ -25,7 +25,6 @@
 #include "Task/Visitors/TaskPointVisitor.hpp"
 #include "Task/TaskBehaviour.hpp"
 #include "Waypoint/Waypoints.hpp"
-#include "Navigation/Aircraft.hpp"
 
 GotoTask::GotoTask(const TaskBehaviour &tb,
                    const Waypoints &wps)
@@ -85,6 +84,7 @@ GotoTask::DoGoto(const Waypoint & wp)
     delete tp;
     tp = new UnorderedTaskPoint(wp, task_behaviour);
     stats.start.Reset();
+    force_full_update = true;
     return true;
   } else {
     return false;
