@@ -81,6 +81,9 @@ static void
 RenderFAISectors(Canvas &canvas, const WindowProjection &projection,
                  const OrderedTask &task)
 {
+  const FAITriangleSettings &settings =
+    task.GetOrderedTaskSettings().fai_triangle;
+
   const unsigned size = task.TaskSize();
   const unsigned end = size - 1;
 
@@ -88,13 +91,13 @@ RenderFAISectors(Canvas &canvas, const WindowProjection &projection,
     RenderFAISector(canvas, projection,
                     task.GetPoint(i).GetLocation(),
                     task.GetPoint(i + 1).GetLocation(),
-                    true);
+                    true, settings);
 
   for (unsigned i = 0; i != end; ++i)
     RenderFAISector(canvas, projection,
                     task.GetPoint(i).GetLocation(),
                     task.GetPoint(i + 1).GetLocation(),
-                    false);
+                    false, settings);
 }
 
 void
@@ -117,14 +120,13 @@ PaintTask(Canvas &canvas, const WindowProjection &projection,
     airspace_renderer.SetAirspaces(airspaces);
 
 #ifndef ENABLE_OPENGL
-    BufferCanvas buffer_canvas, stencil_canvas;
-    buffer_canvas.Create(canvas);
+    BufferCanvas stencil_canvas;
     stencil_canvas.Create(canvas);
 #endif
 
     airspace_renderer.Draw(canvas,
 #ifndef ENABLE_OPENGL
-                           buffer_canvas, stencil_canvas,
+                           stencil_canvas,
 #endif
                            projection, settings_map.airspace);
   }
@@ -136,9 +138,11 @@ PaintTask(Canvas &canvas, const WindowProjection &projection,
 
   if (fai_sectors && IsFAITriangleApplicable(task)) {
     static constexpr Color fill_color = COLOR_YELLOW;
+#if defined(ENABLE_OPENGL) || defined(USE_MEMORY_CANVAS)
 #ifdef ENABLE_OPENGL
-    GLEnable blend(GL_BLEND);
-    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+#endif
+
     canvas.Select(Brush(fill_color.WithAlpha(40)));
     canvas.Select(Pen(1, COLOR_BLACK.WithAlpha(80)));
     RenderFAISectors(canvas, projection, task);
