@@ -24,50 +24,55 @@ Copyright_License {
 #include "Look/AirspaceLook.hpp"
 #include "Screen/Layout.hpp"
 #include "Renderer/AirspaceRendererSettings.hpp"
-#include "resource.h"
+#include "Resources.hpp"
 #include "Util/Macros.hpp"
 
 #ifdef USE_GDI
 #include "Screen/GDI/AlphaBlend.hpp"
 #endif
 
-const Color AirspaceLook::preset_colors[] = {
-  COLOR_RED,
-  COLOR_GREEN,
-  COLOR_BLUE,
-  COLOR_YELLOW,
-  COLOR_MAGENTA,
-  COLOR_CYAN,
-  DarkColor(COLOR_RED),
-  DarkColor(COLOR_GREEN),
-  DarkColor(COLOR_BLUE),
-  DarkColor(COLOR_YELLOW),
-  DarkColor(COLOR_MAGENTA),
-  DarkColor(COLOR_CYAN),
-  COLOR_WHITE,
-  COLOR_LIGHT_GRAY,
-  COLOR_GRAY,
-  COLOR_BLACK,
+const RGB8Color AirspaceLook::preset_colors[] = {
+  RGB8_RED,
+  RGB8_GREEN,
+  RGB8_BLUE,
+  RGB8_YELLOW,
+  RGB8_MAGENTA,
+  RGB8_CYAN,
+  RGB8_RED.Darken(),
+  RGB8_GREEN.Darken(),
+  RGB8_BLUE.Darken(),
+  RGB8_YELLOW.Darken(),
+  RGB8_MAGENTA.Darken(),
+  RGB8_CYAN.Darken(),
+  RGB8_WHITE,
+  RGB8_LIGHT_GRAY,
+  RGB8_GRAY,
+  RGB8_BLACK,
 };
 
+void
+AirspaceClassLook::Initialise(const AirspaceClassRendererSettings &settings)
+{
+  fill_color = Color(settings.fill_color);
+
+#ifdef HAVE_ALPHA_BLEND
+  if (AlphaBlendAvailable())
+#endif
+#if defined(HAVE_ALPHA_BLEND) || !defined(HAVE_HATCHED_BRUSH)
+    solid_brush.Set(fill_color);
+#endif
+
+  if (settings.border_width != 0)
+    border_pen.Set(Layout::ScalePenWidth(settings.border_width),
+                   Color(settings.border_color));
+}
+
 void
 AirspaceLook::Initialise(const AirspaceRendererSettings &settings,
                          const Font &_name_font)
 {
-  for (unsigned i = 0; i < AIRSPACECLASSCOUNT; ++i) {
-    const AirspaceClassRendererSettings &class_settings = settings.classes[i];
-
-    if (class_settings.border_width != 0)
-      pens[i].Set(Layout::ScalePenWidth(class_settings.border_width),
-                  class_settings.border_color);
-
-#ifdef HAVE_ALPHA_BLEND
-    if (AlphaBlendAvailable())
-#endif
-#if defined(HAVE_ALPHA_BLEND) || !defined(HAVE_HATCHED_BRUSH)
-      solid_brushes[i].Set(class_settings.fill_color);
-#endif
-  }
+  for (unsigned i = 0; i < AIRSPACECLASSCOUNT; ++i)
+    classes[i].Initialise(settings.classes[i]);
 
   // airspace brushes and colors
 #ifdef HAVE_HATCHED_BRUSH
@@ -86,7 +91,7 @@ AirspaceLook::Initialise(const AirspaceRendererSettings &settings,
 
   thick_pen.Set(Layout::ScalePenWidth(10), COLOR_BLACK);
 
-  intercept_icon.Load(IDB_AIRSPACEI, IDB_AIRSPACEI_HD);
+  intercept_icon.LoadResource(IDB_AIRSPACEI, IDB_AIRSPACEI_HD);
 
   name_font = &_name_font;
 }
