@@ -25,10 +25,11 @@
 #include "MapSettings.hpp"
 #include "Screen/Ramp.hpp"
 #include "Screen/Layout.hpp"
+#include "Util/Macros.hpp"
 
 #include <algorithm>
 
-static Color
+static RGB8Color
 GetVario1Color(short ramp_h) {
   static constexpr ColorRamp snail_colors_vario[] = {
     {0,   0xc4, 0x80, 0x1e}, // sinkColor
@@ -36,10 +37,11 @@ GetVario1Color(short ramp_h) {
     {200, 0x1e, 0xf1, 0x73} // liftColor
   };
 
-  return ColorRampLookup(ramp_h, snail_colors_vario, 3);
+  return ColorRampLookup(ramp_h, snail_colors_vario,
+                         ARRAY_SIZE(snail_colors_vario));
 }
 
-static Color
+static RGB8Color
 GetVario2Color(short ramp_h) {
   static constexpr ColorRamp snail_colors_vario2[] = {
     {0,   0x00, 0x00, 0xff},
@@ -48,10 +50,11 @@ GetVario2Color(short ramp_h) {
     {200, 0xff, 0x00, 0x00}
   };
 
-  return ColorRampLookup(ramp_h, snail_colors_vario2, 4);
+  return ColorRampLookup(ramp_h, snail_colors_vario2,
+                         ARRAY_SIZE(snail_colors_vario2));
 }
 
-static Color
+static RGB8Color
 GetAltitudeColor(short ramp_h) {
   static constexpr ColorRamp snail_colors_alt[] = {
     {0,   0xff, 0x00, 0x00},
@@ -61,11 +64,14 @@ GetAltitudeColor(short ramp_h) {
     {200, 0x00, 0x00, 0xff},
   };
 
-  return ColorRampLookup(ramp_h, snail_colors_alt, 5);
+  return ColorRampLookup(ramp_h, snail_colors_alt,
+                         ARRAY_SIZE(snail_colors_alt));
 }
 
-static Color
-GetColor(TrailSettings::Type type, short ramp_h) {
+gcc_const
+static RGB8Color
+GetPortableColor(TrailSettings::Type type, short ramp_h)
+{
   switch (type) {
   case TrailSettings::Type::ALTITUDE:
     return GetAltitudeColor(ramp_h);
@@ -78,6 +84,13 @@ GetColor(TrailSettings::Type type, short ramp_h) {
   }
 }
 
+gcc_const
+static Color
+GetColor(TrailSettings::Type type, short ramp_h)
+{
+  return Color(GetPortableColor(type, ramp_h));
+}
+
 void
 TrailLook::Initialise(const TrailSettings &settings)
 {
