@@ -23,7 +23,6 @@ Copyright_License {
 
 #include "FlightStatisticsRenderer.hpp"
 #include "ChartRenderer.hpp"
-#include "FlightStatistics.hpp"
 #include "Util/Macros.hpp"
 #include "Look/MapLook.hpp"
 #include "Task/ProtectedTaskManager.hpp"
@@ -36,15 +35,15 @@ Copyright_License {
 #include "Formatter/TimeFormatter.hpp"
 #include "Units/Units.hpp"
 #include "Language/Language.hpp"
-#include "Computer/Settings.hpp"
+#include "Engine/Contest/Settings.hpp"
 #include "MapSettings.hpp"
-#include "GlideSolvers/GlidePolar.hpp"
 #include "Projection/ChartProjection.hpp"
 #include "Renderer/TaskRenderer.hpp"
 #include "Renderer/TaskPointRenderer.hpp"
 #include "Renderer/OZRenderer.hpp"
 #include "Renderer/AircraftRenderer.hpp"
-#include "Computer/TraceComputer.hpp"
+#include "Engine/Contest/Solvers/Retrospective.hpp"
+#include "Computer/Settings.hpp"
 
 #include <algorithm>
 
@@ -58,13 +57,42 @@ FlightStatisticsRenderer::FlightStatisticsRenderer(const ChartLook &_chart_look,
    map_look(_map_look),
    trail_renderer(map_look.trail) {}
 
+void
+FlightStatisticsRenderer::DrawContestSolution(Canvas &canvas,
+                                              const Projection &projection,
+                                              const ContestStatistics &statistics,
+                                              unsigned i) const
+{
+  if (!statistics.GetResult(i).IsDefined())
+    return;
+
+  canvas.Select(map_look.contest_pens[i]);
+  trail_renderer.DrawTraceVector(canvas, projection,
+                                 statistics.GetSolution(i));
+}
+
+void
+FlightStatisticsRenderer::DrawContestTriangle(Canvas &canvas, const Projection &projection,
+                                              const ContestStatistics &statistics, unsigned i) const
+{
+  if (!statistics.GetResult(i).IsDefined() ||
+      statistics.GetSolution(i).size() != 5)
+    return;
+
+  canvas.Select(map_look.contest_pens[i]);
+  canvas.SelectHollowBrush();
+  trail_renderer.DrawTriangle(canvas, projection,
+                              statistics.GetSolution(i));
+}
+
 void
 FlightStatisticsRenderer::RenderOLC(Canvas &canvas, const PixelRect rc,
-                            const NMEAInfo &nmea_info, 
-                            const ComputerSettings &settings_computer,
-                            const MapSettings &settings_map,
-                            const ContestStatistics &contest,
-                                    const TraceComputer &trace_computer) const
+                                    const NMEAInfo &nmea_info,
+                                    const ComputerSettings &settings_computer,
+                                    const MapSettings &settings_map,
+                                    const ContestStatistics &contest,
+                                    const TraceComputer &trace_computer,
+                                    const Retrospective &retrospective) const
 {
   if (!trail_renderer.LoadTrace(trace_computer)) {
     ChartRenderer chart(chart_look, canvas, rc);
@@ -86,17 +114,54 @@ FlightStatisticsRenderer::RenderOLC(Canvas &canvas, const PixelRect rc,
 
   const ChartProjection proj(rc, task_projection);
 
+  {
+    // draw place names found in the retrospective task
+    //    canvas.Select(*dialog_look.small_font);
+    canvas.Select(chart_look.label_font);
+    canvas.SetBackgroundTransparent();
+
+    for (const auto &i : retrospective.getNearWaypointList()) {
+      RasterPoint wp_pos = proj.GeoToScreen(i.waypoint.location);
+      canvas.DrawText(wp_pos.x,
+                      wp_pos.y,
+                      i.waypoint.name.c_str());
+    }
+  }
+
   RasterPoint aircraft_pos = proj.GeoToScreen(nmea_info.location);
   AircraftRenderer::Draw(canvas, settings_map, map_look.aircraft,
                          nmea_info.attitude.heading, aircraft_pos);
 
   trail_renderer.Draw(canvas, proj);
 
-  for (unsigned i=0; i< 3; ++i) {
-    if (contest.GetResult(i).IsDefined()) {
-      canvas.Select(map_look.contest_pens[i]);
-      trail_renderer.DrawTraceVector(canvas, proj, contest.GetSolution(i));
-    }
+  switch (settings_computer.contest.contest) {
+  case Contest::NONE:
+    break;
+
+  case Contest::OLC_SPRINT:
+  case Contest::OLC_CLASSIC:
+  case Contest::SIS_AT:
+  case Contest::NET_COUPE:
+  case Contest::DMST:
+    DrawContestSolution(canvas, proj, contest, 0);
+    break;
+
+  case Contest::OLC_FAI:
+    DrawContestTriangle(canvas, proj, contest, 0);
+    break;
+
+  case Contest::OLC_LEAGUE:
+    /* draw classic first, and triangle on top of it */
+    DrawContestSolution(canvas, proj, contest, 1);
+    DrawContestSolution(canvas, proj, contest, 0);
+    break;
+
+  case Contest::OLC_PLUS:
+  case Contest::XCONTEST:
+  case Contest::DHV_XC:
+    DrawContestSolution(canvas, proj, contest, 0);
+    DrawContestTriangle(canvas, proj, contest, 1);
+    break;
   }
 }
 
@@ -189,9 +254,9 @@ FlightStatisticsRenderer::CaptionOLC(TCHAR *sTmp,
 
 void
 FlightStatisticsRenderer::RenderTask(Canvas &canvas, const PixelRect rc,
-                             const NMEAInfo &nmea_info, 
-                             const ComputerSettings &settings_computer,
-                             const MapSettings &settings_map,
+                                     const NMEAInfo &nmea_info,
+                                     const ComputerSettings &settings_computer,
+                                     const MapSettings &settings_map,
                                      const ProtectedTaskManager &_task_manager,
                                      const TraceComputer *trace_computer) const
 {
@@ -242,8 +307,8 @@ FlightStatisticsRenderer::CaptionTask(TCHAR *sTmp, const DerivedInfo &derived)
     const fixed d_remaining = derived.task_stats.total.remaining.GetDistance();
     TCHAR timetext1[100];
     TCHAR timetext2[100];
-    if (common.ordered_has_targets) {
-      FormatSignedTimeHHMM(timetext1, (int)task_stats.total.time_remaining);
+    if (task_stats.has_targets) {
+      FormatSignedTimeHHMM(timetext1, (int)task_stats.total.time_remaining_start);
       FormatSignedTimeHHMM(timetext2, (int)common.aat_time_remaining);
 
       if (Layout::landscape) {
@@ -267,7 +332,7 @@ FlightStatisticsRenderer::CaptionTask(TCHAR *sTmp, const DerivedInfo &derived)
             Units::GetTaskSpeedName());
       }
     } else {
-      FormatSignedTimeHHMM(timetext1, (int)task_stats.total.time_remaining);
+      FormatSignedTimeHHMM(timetext1, (int)task_stats.total.time_remaining_now);
       _stprintf(sTmp, _T("%s: %s\r\n%s: %5.0f %s\r\n"),
                 _("Task to go"), timetext1, _("Distance to go"),
                 (double)Units::ToUserDistance(d_remaining),
