@@ -32,28 +32,21 @@ Copyright_License {
 #include "Engine/Waypoint/Waypoint.hpp"
 #include "Engine/Waypoint/Waypoints.hpp"
 #include "Engine/Waypoint/WaypointVisitor.hpp"
-#include "Engine/Navigation/Aircraft.hpp"
 #include "Engine/GlideSolvers/GlideState.hpp"
 #include "Engine/GlideSolvers/GlideResult.hpp"
 #include "Engine/GlideSolvers/MacCready.hpp"
+#include "Engine/Task/AbstractTask.hpp"
 #include "Engine/Task/Unordered/UnorderedTaskPoint.hpp"
-#include "Engine/Task/Unordered/GotoTask.hpp"
-#include "Engine/Task/Unordered/AbortTask.hpp"
-#include "Engine/Task/Ordered/Points/StartPoint.hpp"
-#include "Engine/Task/Ordered/Points/FinishPoint.hpp"
-#include "Engine/Task/Ordered/Points/ASTPoint.hpp"
-#include "Engine/Task/Ordered/Points/AATPoint.hpp"
+#include "Engine/Task/Ordered/Points/OrderedTaskPoint.hpp"
 #include "Task/ProtectedTaskManager.hpp"
 #include "Task/ProtectedRoutePlanner.hpp"
-#include "Screen/Icon.hpp"
 #include "Screen/Canvas.hpp"
 #include "Units/Units.hpp"
-#include "Screen/Layout.hpp"
 #include "Util/StaticArray.hpp"
 #include "NMEA/MoreData.hpp"
 #include "NMEA/Derived.hpp"
 #include "Engine/Route/ReachResult.hpp"
-#include "Look/Fonts.hpp"
+#include "Look/WaypointLook.hpp"
 
 #include <assert.h>
 #include <stdio.h>
@@ -144,6 +137,10 @@ class WaypointVisitorMap:
   const WaypointLook &look;
   const TaskBehaviour &task_behaviour;
   const MoreData &basic;
+  /**
+   * is the ordered task a MAT
+   */
+  bool is_mat;
 
   TCHAR sAltUnit[4];
   bool task_valid;
@@ -169,12 +166,20 @@ public:
     :projection(_projection),
      settings(_settings), look(_look), task_behaviour(_task_behaviour),
      basic(_basic),
+     is_mat(false),
      task_valid(false),
      labels(projection.GetScreenWidth(), projection.GetScreenHeight())
   {
     _tcscpy(sAltUnit, Units::GetAltitudeName());
   }
 
+  /**
+   * Indicate the ordered task is a MAT
+   */
+  void SetIsMat(bool v) {
+    is_mat = v;
+  }
+
 protected:
   void
   FormatTitle(TCHAR* Buffer, const Waypoint &way_point)
@@ -366,7 +371,7 @@ public:
   void
   Visit(const Waypoint& way_point)
   {
-    AddWaypoint(way_point, false);
+    AddWaypoint(way_point, way_point.IsTurnpoint() && is_mat);
   }
 
   virtual void Visit(const TaskPoint &tp) override {
@@ -442,12 +447,13 @@ public:
 static void
 MapWaypointLabelRender(Canvas &canvas, UPixelScalar width, UPixelScalar height,
                        LabelBlock &label_block,
-                       WaypointLabelList &labels)
+                       WaypointLabelList &labels,
+                       const WaypointLook &look)
 {
   labels.Sort();
 
   for (const auto &l : labels) {
-    canvas.Select(l.bold ? Fonts::map_bold : Fonts::map);
+    canvas.Select(l.bold ? *look.bold_font : *look.font);
 
     TextInBox(canvas, l.Name, l.Pos.x, l.Pos.y, l.Mode,
               width, height, &label_block);
@@ -472,11 +478,14 @@ WaypointRenderer::render(Canvas &canvas, LabelBlock &label_block,
   if (task != NULL) {
     ProtectedTaskManager::Lease task_manager(*task);
 
+    const TaskStats &task_stats = task_manager->GetStats();
+
+    v.SetIsMat(task_stats.is_mat);
+
     // task items come first, this is the only way we know that an item is in task,
     // and we won't add it if it is already there
-    if (task_manager->StatsValid()) {
+    if (task_stats.task_valid)
       v.set_task_valid();
-    }
 
     const AbstractTask *atask = task_manager->GetActiveTask();
     if (atask != NULL)
@@ -493,5 +502,5 @@ WaypointRenderer::render(Canvas &canvas, LabelBlock &label_block,
   MapWaypointLabelRender(canvas,
                          projection.GetScreenWidth(),
                          projection.GetScreenHeight(),
-                         label_block, v.labels);
+                         label_block, v.labels, look);
 }
