@@ -447,10 +447,15 @@ public:
           DrawThickLine(p_this.x, p_this.y, p_last.x, p_last.y, thickness, color, line_mask);
         else
           DrawLineDirect(p_this.x, p_this.y, p_last.x, p_last.y, color, line_mask);
-        last_visible = true;
-        p_last = p_this;
-        code2 = code1;
-        code2_orig = code1_orig;
+        if (code1 == code1_orig) {
+          last_visible = true;
+          p_last = p_this;
+          code2 = code1;
+          code2_orig = code1_orig;
+        } else {
+          last_visible = false;
+          p_last = points[i];
+        }
       } else {
         last_visible = false;
         p_last = points[i];
