@@ -526,6 +526,36 @@ Canvas::CalcTextSize(const TCHAR *text) const
   return TextCache::GetSize(*font, text);
 }
 
+/**
+ * Prepare drawing a GL_ALPHA texture with the specified color.
+ */
+static void
+PrepareColoredAlphaTexture(Color color)
+{
+  color.Set();
+
+  if (color == COLOR_BLACK) {
+    /* GL_ALPHA textures have black RGB - this is easy */
+
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
+  } else {
+    /* use GL_COMBINE to replace the texture color (black) with the
+       specified one */
+
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
+
+    /* replace the texture color with the selected text color */
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_RGB, GL_REPLACE);
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SRC0_RGB, GL_PREVIOUS);
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_RGB, GL_SRC_COLOR);
+
+    /* use the texture alpha */
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_ALPHA, GL_REPLACE);
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SRC0_ALPHA, GL_TEXTURE);
+    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_ALPHA, GL_SRC_ALPHA);
+  }
+}
+
 void
 Canvas::DrawText(int x, int y, const TCHAR *text)
 {
@@ -544,28 +574,17 @@ Canvas::DrawText(int x, int y, const TCHAR *text)
     return;
 
   if (background_mode == OPAQUE)
-    /* draw the opaque background */
     DrawFilledRectangle(x, y,
                         x + texture->GetWidth(), y + texture->GetHeight(),
                         background_color);
 
+  PrepareColoredAlphaTexture(text_color);
+
   GLEnable scope(GL_TEXTURE_2D);
+  const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
   texture->Bind();
-  GLLogicOp logic_op(GL_AND_INVERTED);
-
-  if (background_mode != OPAQUE || background_color != COLOR_BLACK) {
-    /* cut out the shape in black */
-    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-    texture->Draw(x, y);
-  }
-
-  if (text_color != COLOR_BLACK) {
-    /* draw the text color on top */
-    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-    logic_op.set(GL_OR);
-    text_color.Set();
-    texture->Draw(x, y);
-  }
+  texture->Draw(x, y);
 }
 
 void
@@ -585,21 +604,13 @@ Canvas::DrawTransparentText(int x, int y, const TCHAR *text)
   if (texture == NULL)
     return;
 
+  PrepareColoredAlphaTexture(text_color);
+
   GLEnable scope(GL_TEXTURE_2D);
+  const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
   texture->Bind();
-  GLLogicOp logic_op(GL_AND_INVERTED);
-
-  /* cut out the shape in black */
-  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
   texture->Draw(x, y);
-
-  if (text_color != COLOR_BLACK) {
-    /* draw the text color on top */
-    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-    logic_op.set(GL_OR);
-    text_color.Set();
-    texture->Draw(x, y);
-  }
 }
 
 void
@@ -621,26 +632,18 @@ Canvas::DrawClippedText(int x, int y,
   if (texture == NULL)
     return;
 
-  GLEnable scope(GL_TEXTURE_2D);
-  texture->Bind();
-  GLLogicOp logic_op(GL_AND_INVERTED);
-
   if (texture->GetHeight() < height)
     height = texture->GetHeight();
   if (texture->GetWidth() < width)
     width = texture->GetWidth();
 
-  /* cut out the shape in black */
-  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-  texture->Draw(x, y, width, height, 0, 0, width, height);
+  PrepareColoredAlphaTexture(text_color);
 
-  if (text_color != COLOR_BLACK) {
-    /* draw the text color on top */
-    OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-    logic_op.set(GL_OR);
-    text_color.Set();
-    texture->Draw(x, y, width, height, 0, 0, width, height);
-  }
+  GLEnable scope(GL_TEXTURE_2D);
+  const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+  texture->Bind();
+  texture->Draw(x, y, width, height, 0, 0, width, height);
 }
 
 void
@@ -744,71 +747,26 @@ Canvas::StretchMono(int dest_x, int dest_y,
      implementation will be faster when erasing the background
      again */
 
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
+
+  /* replace the texture color with the selected text color */
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_RGB, GL_REPLACE);
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SRC0_RGB, GL_PREVIOUS);
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_RGB, GL_SRC_COLOR);
+
+  /* invert texture alpha (our bitmaps have black text on white
+     background) */
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_ALPHA, GL_REPLACE);
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SRC0_ALPHA, GL_TEXTURE);
+  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+  const GLEnable scope(GL_TEXTURE_2D);
+  const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
   GLTexture &texture = *src.GetNative();
-  GLEnable scope(GL_TEXTURE_2D);
   texture.Bind();
-
-  OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
-
-  if (fg_color == COLOR_WHITE) {
-    /* white text requested: use this trivial implementation */
-    GLLogicOp logic_op(GL_OR_INVERTED);
-    texture.Draw(dest_x, dest_y, dest_width, dest_height,
-                 src_x, src_y, src_width, src_height);
-    return;
-  }
-
-  /* apply the mask, pixels will be black then */
-  GLLogicOp logic_op(GL_AND);
-  if (bg_color != COLOR_BLACK)
-    texture.Draw(dest_x, dest_y, dest_width, dest_height,
-                 src_x, src_y, src_width, src_height);
-
-  if (fg_color != COLOR_BLACK) {
-    /* draw */
-
-#ifndef HAVE_GLES
-    if (fg_color != COLOR_WHITE) {
-      /* XXX OpenGL/ES doesn't support GL_OPERAND0_RGB; we can't print
-         colored mono images currently */
-
-      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
-      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SOURCE0_RGB, GL_TEXTURE);
-      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND0_RGB,
-                        GL_ONE_MINUS_SRC_COLOR);
-
-      const GLfloat color[] = {
-        GLfloat(fg_color.Red() / 256.),
-        GLfloat(fg_color.Green() / 256.),
-        GLfloat(fg_color.Blue() / 256.),
-        GLfloat(1.0),
-      };
-
-      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_SOURCE1_RGB, GL_CONSTANT);
-      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_OPERAND1_RGB, GL_SRC_COLOR);
-      OpenGL::glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_RGB, GL_MODULATE);
-      glTexEnvfv(GL_TEXTURE_ENV, GL_TEXTURE_ENV_COLOR, color);
-
-      logic_op.set(GL_OR);
-    } else
-#endif
-      logic_op.set(GL_OR_INVERTED);
-
-    texture.Draw(dest_x, dest_y, dest_width, dest_height,
-                 src_x, src_y, src_width, src_height);
-  }
-}
-
-void
-Canvas::CopyOr(int dest_x, int dest_y,
-               unsigned dest_width, unsigned dest_height,
-               const Bitmap &src, int src_x, int src_y)
-{
-  assert(src.IsDefined());
-
-  GLLogicOp logic_op(GL_OR);
-  Copy(dest_x, dest_y, dest_width, dest_height,
-       src, src_x, src_y);
+  texture.Draw(dest_x, dest_y, dest_width, dest_height,
+               src_x, src_y, src_width, src_height);
 }
 
 void
@@ -835,18 +793,6 @@ Canvas::CopyAnd(int dest_x, int dest_y,
        src, src_x, src_y);
 }
 
-void
-Canvas::CopyNot(int dest_x, int dest_y,
-                unsigned dest_width, unsigned dest_height,
-                const Bitmap &src, int src_x, int src_y)
-{
-  assert(src.IsDefined());
-
-  GLLogicOp logic_op(GL_COPY_INVERTED);
-  Copy(dest_x, dest_y, dest_width, dest_height,
-       src, src_x, src_y);
-}
-
 void
 Canvas::CopyToTexture(GLTexture &texture, PixelRect src_rc) const
 {
